/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OpensearchOutboundConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#connection_alias OpensearchOutboundConnection#connection_alias}
    */
    readonly connectionAlias: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#id OpensearchOutboundConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * local_domain_info block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#local_domain_info OpensearchOutboundConnection#local_domain_info}
    */
    readonly localDomainInfo: OpensearchOutboundConnectionLocalDomainInfo;
    /**
    * remote_domain_info block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#remote_domain_info OpensearchOutboundConnection#remote_domain_info}
    */
    readonly remoteDomainInfo: OpensearchOutboundConnectionRemoteDomainInfo;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#timeouts OpensearchOutboundConnection#timeouts}
    */
    readonly timeouts?: OpensearchOutboundConnectionTimeouts;
}
export interface OpensearchOutboundConnectionLocalDomainInfo {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#domain_name OpensearchOutboundConnection#domain_name}
    */
    readonly domainName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#owner_id OpensearchOutboundConnection#owner_id}
    */
    readonly ownerId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#region OpensearchOutboundConnection#region}
    */
    readonly region: string;
}
export declare function opensearchOutboundConnectionLocalDomainInfoToTerraform(struct?: OpensearchOutboundConnectionLocalDomainInfoOutputReference | OpensearchOutboundConnectionLocalDomainInfo): any;
export declare class OpensearchOutboundConnectionLocalDomainInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OpensearchOutboundConnectionLocalDomainInfo | undefined;
    set internalValue(value: OpensearchOutboundConnectionLocalDomainInfo | undefined);
    private _domainName?;
    get domainName(): string;
    set domainName(value: string);
    get domainNameInput(): string | undefined;
    private _ownerId?;
    get ownerId(): string;
    set ownerId(value: string);
    get ownerIdInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface OpensearchOutboundConnectionRemoteDomainInfo {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#domain_name OpensearchOutboundConnection#domain_name}
    */
    readonly domainName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#owner_id OpensearchOutboundConnection#owner_id}
    */
    readonly ownerId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#region OpensearchOutboundConnection#region}
    */
    readonly region: string;
}
export declare function opensearchOutboundConnectionRemoteDomainInfoToTerraform(struct?: OpensearchOutboundConnectionRemoteDomainInfoOutputReference | OpensearchOutboundConnectionRemoteDomainInfo): any;
export declare class OpensearchOutboundConnectionRemoteDomainInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OpensearchOutboundConnectionRemoteDomainInfo | undefined;
    set internalValue(value: OpensearchOutboundConnectionRemoteDomainInfo | undefined);
    private _domainName?;
    get domainName(): string;
    set domainName(value: string);
    get domainNameInput(): string | undefined;
    private _ownerId?;
    get ownerId(): string;
    set ownerId(value: string);
    get ownerIdInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface OpensearchOutboundConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#create OpensearchOutboundConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection#delete OpensearchOutboundConnection#delete}
    */
    readonly delete?: string;
}
export declare function opensearchOutboundConnectionTimeoutsToTerraform(struct?: OpensearchOutboundConnectionTimeouts | cdktf.IResolvable): any;
export declare class OpensearchOutboundConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OpensearchOutboundConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: OpensearchOutboundConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection aws_opensearch_outbound_connection}
*/
export declare class OpensearchOutboundConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "aws_opensearch_outbound_connection";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.13.1/docs/resources/opensearch_outbound_connection aws_opensearch_outbound_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OpensearchOutboundConnectionConfig
    */
    constructor(scope: Construct, id: string, config: OpensearchOutboundConnectionConfig);
    private _connectionAlias?;
    get connectionAlias(): string;
    set connectionAlias(value: string);
    get connectionAliasInput(): string | undefined;
    get connectionStatus(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _localDomainInfo;
    get localDomainInfo(): OpensearchOutboundConnectionLocalDomainInfoOutputReference;
    putLocalDomainInfo(value: OpensearchOutboundConnectionLocalDomainInfo): void;
    get localDomainInfoInput(): OpensearchOutboundConnectionLocalDomainInfo | undefined;
    private _remoteDomainInfo;
    get remoteDomainInfo(): OpensearchOutboundConnectionRemoteDomainInfoOutputReference;
    putRemoteDomainInfo(value: OpensearchOutboundConnectionRemoteDomainInfo): void;
    get remoteDomainInfoInput(): OpensearchOutboundConnectionRemoteDomainInfo | undefined;
    private _timeouts;
    get timeouts(): OpensearchOutboundConnectionTimeoutsOutputReference;
    putTimeouts(value: OpensearchOutboundConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | OpensearchOutboundConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
